==> revealer-2.0.6-win64.zip: README.md <==
# Revealer

Программа для поиска сетевых устройств в локальной сети.

## Запуск и использование

1. Выберете приложение для вашей операционной системы и запустите его.
2. Нажмите кнопку __Search__, чтобы получить / обновить список найденных сетевых устройств, поддерживающих SSDP-поиск.
3. В полученном списке доступные устройства, находящиеся в той же локальной сети, что и Ваш компьютер, будут иметь в графе URL выделенную ссылку (синего цвета с подчеркиванием). Их страницы могут быть открыты кликом левой кнопкой мыши по соответвующей ячейке столбца _URL_.
4. Справа от ссылок в соответсвующей строке будет иконка информации об устройстве (i) - при нажатии на неё можно октрыть список свойств данного устройства.
5. Для недоступных для Вашего компьютера устройств указан их IP-адрес в другой сети.
6. Для наших устройств, которые поддерживают этот протокол, доступна опция изменения IP-адреса из другой сети. Для этого:
  ** С помощью нажатия на иконку с двумя шестеренками откройте окно __Change settings...__. Если данная опция недоступна, значит, версия устройства её не поддерживает.
  ** в открывшимся окне введите пароль устройства, выберете или уберите галочку с DHCP опции, укажите желаемый IP-адрес, маску подсети и при необходимости шлюз по умолчанию.
  ** нажмите __Ок__.
  ** через некоторое время появится окно с результатом выполнения, если изменение IP-адреса было успешно, то данное устройство пропадет из списка.
  ** обновите список устройств кнопкой __Search__, чтобы найти это устройство с новым адресом.

Обратите внимание, что для поиска устройств в другой сети может потребоваться отключение брандмауэра.

==> revealer-2.0.8-win64.zip: README.md <==
# Revealer

Программа для поиска сетевых устройств в локальной сети.

## Запуск и использование

1. Выберете приложение для вашей операционной системы и запустите его.
2. Нажмите кнопку __Search__, чтобы получить / обновить список найденных сетевых устройств, поддерживающих SSDP-поиск.
3. В полученном списке доступные устройства, находящиеся в той же локальной сети, что и Ваш компьютер, будут иметь в графе URL выделенную ссылку (синего цвета с подчеркиванием). Их страницы могут быть открыты кликом левой кнопкой мыши по соответствующей ячейке столбца _URL_.
4. Справа от ссылок в соответствующей строке будет иконка информации об устройстве (i) - при нажатии на неё можно открыть список свойств данного устройства.
5. Для недоступных для Вашего компьютера устройств указан их IP-адрес в другой сети.
6. Для наших устройств, которые поддерживают этот протокол, доступна опция изменения IP-адреса из другой сети. Для этого:
  ** С помощью нажатия на иконку с двумя шестеренками откройте окно __Change settings...__. Если данная опция недоступна, значит, версия устройства её не поддерживает.
  ** в открывшимся окне введите пароль устройства, выберете или уберите галочку с DHCP опции, укажите желаемый IP-адрес, маску подсети и при необходимости шлюз по умолчанию.
  ** нажмите __Ок__.
  ** через некоторое время появится окно с результатом выполнения, если изменение IP-адреса было успешно, то данное устройство пропадет из списка.
  ** обновите список устройств кнопкой __Search__, чтобы найти это устройство с новым адресом.

Обратите внимание, что для поиска устройств в другой сети может потребоваться отключение брандмауэра.

Кроме того, для корректной работы программы Revealer на виртуальной машине нужно указать в её настройках тип подключения "Сетевой мост" (Сеть->Адаптер 1->Тип подключения).
